Package: hereR
Type: Package
Title: 'sf'-Based Interface to the 'HERE' REST APIs
Version: 1.1.0
Authors@R: c(
    person("Merlin", "Unterfinger", role = c("aut", "cre"), email = "info@munterfinger.ch", comment = c(ORCID = "0000-0003-2020-2366")),
    person("Daniel", "Possenriede", role = "ctb", comment = c(ORCID = "0000-0002-6738-9845")))
Maintainer: Merlin Unterfinger <info@munterfinger.ch>
URL: https://munterfi.github.io/hereR/,
        https://github.com/munterfi/hereR/
BugReports: https://github.com/munterfi/hereR/issues/
Description: Interface to the 'HERE' REST APIs <https://developer.here.com/develop/rest-apis>:
  (1) geocode and autosuggest addresses or reverse geocode POIs using the 'Geocoder' API;
  (2) route directions, travel distance or time matrices and isolines using the 'Routing', 'Matrix Routing' and 'Isoline Routing' APIs;
  (3) request real-time traffic flow and incident information from the 'Traffic' API;
  (4) find request public transport connections and nearby stations from the 'Public Transit' API;
  (5) request intermodal routes using the 'Intermodal Routing' API;
  (6) get weather forecasts, reports on current weather conditions, astronomical
  information and alerts at a specific location from the 'Destination Weather' API.
  Locations, routes and isolines are returned as 'sf' objects.
Depends: R (>= 3.3.0)
Imports: crul (>= 1.1.0), curl (>= 4.3), data.table (>= 1.13.0),
        flexpolyline (>= 0.2.0), jsonlite (>= 1.7.0), sf (>= 0.9-0),
        stringr (>= 1.4.0)
Suggests: covr (>= 3.5.0), ggplot2 (>= 3.3.2), htmlwidgets (>= 1.5.1),
        knitr (>= 1.29), leafpop (>= 0.0.5), lwgeom (>= 0.2-5), mapview
        (>= 2.9.0), rmarkdown (>= 2.3), testthat (>= 2.3.2)
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-02-20 16:52:03 UTC; munterfi
Author: Merlin Unterfinger [aut, cre] (<https://orcid.org/0000-0003-2020-2366>),
  Daniel Possenriede [ctb] (<https://orcid.org/0000-0002-6738-9845>)
Repository: CRAN
Date/Publication: 2025-02-20 17:10:01 UTC
Built: R 4.6.0; ; 2026-04-26 08:01:59 UTC; unix
