# Generated by roxygen2: do not edit by hand

S3method(geocode,character)
S3method(geocode,list)
S3method(weather,character)
S3method(weather,sf)
S3method(weather,sfc)
export(autosuggest)
export(connection)
export(flow)
export(geocode)
export(incident)
export(intermodal_route)
export(isoline)
export(reverse_geocode)
export(route)
export(route_matrix)
export(set_currency)
export(set_freemium)
export(set_key)
export(set_verbose)
export(station)
export(unset_key)
export(weather)
import(data.table)
import(sf)
