---
title: "Destination Weather API"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Destination Weather API}
  %\VignetteEncoding{UTF-8}
  %\VignetteEngine{knitr::rmarkdown}
editor_options:
  chunk_output_type: console
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(hereR)

if (requireNamespace("mapview", quietly = TRUE)) {
  mapview::mapviewOptions(
    fgb = FALSE,
    vector.palette = colorRampPalette(
      c("#0571B0", "#92C5DE", "#F7F7F7", "#F4A582", "#CA0020")
    )
  )
}

observation <- hereR:::example$weather_observation
forecast <- hereR:::example$weather_forecast_hourly
astronomy <- hereR:::example$weather_forecast_astronomy
alerts <- hereR:::example$weather_alerts
```

Weather forecasts, reports on current weather conditions, astronomical information and alerts at a specific location based on the 'HERE Destination Weather' API.

## Observations

In order to request information about the current weather situation points of interest (POIs) have to be provided. The POIs must be an `sf` object containing geometries of type `POINT` or a `character` vector containing place names (e.g. cities).
These POIs are passed to the `weather()` function, whereby the `product` parameter is set to `"observation"`:

```{r observations, eval = FALSE}
observation <- weather(
  poi = poi,
  product = "observation"
)
```

The return value is an `sf` object, which contains the `POINT` geometries of the provided POIs and the most recent record on the observed weather. The measurements are taken from the nearest weather observation stations with respect to the POIs. The distance of the stations to the provided POIs is an indicator for the reliabilty of the weather information at each POI. A table of the observed weather near the example POIs:

```{r table_obs, eval=TRUE, fig.align='center', out.width='100%', echo=FALSE, screenshot.force=FALSE}
cols <- c(
  "id", "city", "distance", "daylight", "description", "sky_info", "sky_desc",
  "temperature", "temperature_desc", "comfort", "high_temperature",
  "low_temperature", "humidity", "dew_point", "precipitation_probability",
  "rain_fall", "wind_speed", "wind_direction", "wind_descr", "wind_descr_short",
  "uv_index", "uv_descr", "barometer_pressure", "barometer_trend"
)
knitr::kable(as.data.frame(observation)[, cols], format = "html")
```

Print the weather observation information on an interactive leaflet map:

```{r map_obs, eval=FALSE, out.width='100%'}
if (requireNamespace("mapview", quietly = TRUE)) {
  m <-
    mapview::mapview(observation,
      zcol = "temperature",
      cex = observation$humidity / 10,
      layer.name = "Observation",
      map.types = c("Esri.WorldTopoMap"),
      homebutton = FALSE
    ) +
    mapview::mapview(poi,
      zcol = "city",
      cex = 1,
      col.region = "black",
      legend = FALSE,
      homebutton = FALSE
    )
  m
}
```

## Forecast

An hourly forecast of the predicted weather for the following seven days can be obtained by setting the `product` parameter to `"forecast_hourly"`:

```{r forecast, eval = FALSE}
forecast <- weather(
  poi = poi,
  product = "forecast_hourly"
)
```

Print the weather observation information on an interactive leaflet map with popup graphs for temperature and humidity:

1. Create a list containing the temperature and humidity graphs for every POI:

```{r plots_forecast, eval=TRUE, out.width='100%'}
if (requireNamespace("ggplot2", quietly = TRUE)) {
  g <- lapply(seq_len(nrow(forecast)), function(x) {
    df <- forecast$forecasts[[x]]
    ggplot2::ggplot(df, ggplot2::aes(x = time)) +
      ggplot2::geom_line(ggplot2::aes(y = temperature, color = "Temperature")) +
      ggplot2::geom_line(ggplot2::aes(y = humidity / 5, color = "Humidity")) +
      ggplot2::scale_y_continuous(sec.axis = ggplot2::sec_axis(~ . * 5, name = "Relative humidity [%]")) +
      ggplot2::scale_color_manual(values = c("blue", "red")) +
      ggplot2::labs(y = "Air temperature [°C]", x = "", colour = "") +
      ggplot2::ggtitle(forecast$city[x]) +
      ggplot2::theme_minimal() +
      ggplot2::theme(legend.position = "bottom", panel.background = ggplot2::element_rect(color = NA))
  })
}
```

2. Then add list of graphs to the leaflet map using the the `popup` parameter:

```{r map_forecast, eval=FALSE, out.width='100%'}
if (requireNamespace(c("ggplot2", "mapview", "leafpop"), quietly = TRUE)) {
  m <-
    mapview::mapview(forecast,
      color = "black",
      col.region = "yellow",
      layer.name = "Weather station",
      zcol = "city",
      map.types = c("Esri.WorldTopoMap"),
      homebutton = FALSE,
      legend = FALSE,
      popup = leafpop::popupGraph(g)
    ) +
    mapview::mapview(poi,
      zcol = "city",
      cex = 1,
      col.region = "black",
      layer.name = "POI",
      legend = FALSE,
      homebutton = FALSE
    )
  m
}
```

## Astronomy

An astronomical forecast is requested by setting the `product` parameter to `"forecast_astronomy"`:

```{r astronomy, eval = FALSE}
astronomy <- weather(
  poi = poi,
  product = "forecast_astronomy"
)
```

Print a table for the sun and moon times of the first example POI, where the nearest station is 'Emmenbrücke':

```{r table_ast, eval=TRUE, fig.align='center', out.width='100%', echo=FALSE, screenshot.force=FALSE}
knitr::kable(astronomy$forecasts[[1]], format = "html")
```

## Alerts

Current weather alerts, near provided POIs, are obtain by the product `alerts`:

```{r alerts, eval = FALSE}
alerts <- weather(
  poi = poi,
  product = "alerts"
)
```

This returns an `sf` object with the POIs and the attribute `"alerts"`, which contains the current weather alerts.
If no alerts are recorded near a POI the attribute `"alerts"` is `NULL`.

## API Reference

- [Destination Weather API](https://www.here.com/docs/bundle/destination-weather-api-developer-guide/page/topics/guide.html)
